@@ -19,17 +19,18 @@
 ##############################################################################
 
 from zope.location import Location
-from zope.interface import implements, directlyProvides
-from zope.traversing.interfaces import IContainmentRoot
-from zope.security.checker import ProxyFactory, NamesChecker
+from zope.interface import implements
 from interfaces import IControl
 
-controlRoot = Location()
-directlyProvides(controlRoot, IContainmentRoot)
-controlRoot = ProxyFactory(controlRoot, NamesChecker("__class__"))
+class Control(Location):
+    implements(IControl)
 
-class Control(Location): implements(IControl)
-
-control = Control()
-control.__parent__ = controlRoot
-control.__name__ = u'++etc++control'
+    def get_content(self):
+        # recursive search to avoid confusion if
+        # [ ++control++/++control++ ] or something like
+        def content(x):
+            if IControl.providedBy(x):
+                return content(x.__parent__)
+            else:
+                return x
+        return content(self.__parent__)
